Fishery selectivity-at-age
selectivity_at_age.RdBuild a selectivity-at-age vector from a selectivity specification.
Arguments
- ages
Numeric vector of ages (e.g.,
a_min:a_max).- selectivity
A named list specifying selectivity. Required element
type. Fortype="vector", provides. Fortype="knife_edge", providea_c. Fortype="logistic", providea50anddelta.- scale_max
Logical. If
TRUE, scales selectivity so thatmax(s_a) = 1when possible.
Value
Numeric vector of length length(ages) with values in \([0,1]\).
When selectivity$type == "fleets", the returned vector is the effective
selectivity-at-age.
Details
This is a user-facing wrapper around an internal helper used by
spr_input(). It is useful for sensitivity analyses where the user wants to
modify the fishery selectivity specification of an existing spr_input()
object.
It returns selectivity bounded to \([0,1]\) and can optionally scale so that
max(s_a) = 1.